class Certificate
  include Mongoid::Document
  include Mongoid::Timestamps
  include OrbitModel::Status
  include MemberHelper
  include Slug

  field :issued_by
  field :title, as: :slug_title, type: String, localize: true

  belongs_to :member_profile

  index({title: 1, _id: -1}, { unique: false, background: false })
  scope :sort_title, ->{ order_by(:title => "asc", :id=>"desc") }
  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:title =>'asc',:id =>'desc') }

  def self.get_plugin_datas_to_member(datas)
    page = Page.where(:module => "personal_certificate").first rescue nil

    if !page.nil? && !page.custom_array_field.blank?
      fields_to_show = page.custom_array_field
    else
      fields_to_show = [
        "title",
        "issued_by"
      ]
    end

    fields_to_remove = []

    pd_title = []

    fields_to_show.each do |t|
      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil, t.to_sym.ne => "").count == 0 rescue false)
      else
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
      end
      pd_title <<  {
          "plugin_data_title" => I18n.t("personal_certificate.#{t}")
        } if !fields_to_remove.include?(t)
    end

    fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect.with_index do |p,index|
      pd_data = []
      fields_to_show.collect do |t|
        if t == "title"
          link = OrbitHelper.url_to_plugin_show(p.to_param,'personal_certificate')
          url_to_plugin_show_blank = OrbitHelper.instance_variable_get(:@url_to_plugin_show_blank)
          tmp_title = p.title
          pd_data << { "data_title" => (url_to_plugin_show_blank ? tmp_title : "<a title=\"#{tmp_title}\" href=\"#{link}\" target=\"_blank\">#{tmp_title}</a>") }
        else
          pd_data << { "data_title" => p.send(t) }
        end
      end
      {
        "pd_datas" => pd_data
      }
    end
    return [pd_title,plugin_datas]
  end

  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end

  def get_plugin_field_data(field)
    value = self.send(field) rescue ""
    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href='#{value}' target='blank'>#{value}</a>" : value
    
    {
      "key"=>field,
      "title_class"=>"certificate-#{field.gsub('_','-')}-field",
      "value_class"=>"certificate-#{field.gsub('_','-')}-value",
      "title"=>I18n.t('personal_certificate.'+field),
      "value"=>value
    }
  end

end